import asyncio
from bleak import BleakScanner, BleakClient

# UUID for the characteristic to interact with
SERVICE_UUID = '00000001-710e-4a5b-8d75-3e5b444bc3cf'
CHARACTERISTIC_UUID = '00000002-710e-4a5b-8d75-3e5b444bc3cf'


async def discover_devices():
    print("Scanning for BLE devices...")
    devices = await BleakScanner.discover()

    if not devices:
        print("No BLE devices found. Make sure the devices are in range and advertising.")
        return None

    print("\nFound devices:")
    devices = list(filter(lambda device: device.name != None, devices))
    for i, device in enumerate(devices):
        print(f"{i}: {device.name} - {device.address}")

    # Ask the user to select a device to connect to
    selected_device_index = int(input("\nSelect the device number you want to connect to: "))
    if 0 <= selected_device_index < len(devices):
        return devices[selected_device_index]
    else:
        print("Invalid selection.")
        return None


async def connect_and_interact(device):
    # print("Address: ", device.address)
    async with BleakClient("D8:3A:DD:D0:7C:61") as client:
    # async with BleakClient(device.address) as client:
        # print(f"\nConnected to {device.name} ({device.address})")

        # for key, item in client.services.services.items():
        #     print("Services:", key, item)
        #     print(item.characteristics, item.description)

        # Check if the service and characteristic are available on the device
        services = client.services
        # print("Characteristics:")
        # for key, item in services.characteristics.items():
        #     print(key, "|", item)

        for key, item in services.characteristics.items():
            uuid, name, properties = item.uuid, item.description, item.properties
            print(name, uuid, properties)

        temp = services.get_characteristic(CHARACTERISTIC_UUID)
        print("Properties:", temp.properties)
        print("Description:", temp.description)

        for i in range(1):
            data = await client.read_gatt_char(CHARACTERISTIC_UUID)
            print(data.decode())
            # await client.write_gatt_char("00000003-710e-4a5b-8d75-3e5b444bc3cf", input("C or F: ").encode())
        


async def main():
    # Discover BLE devices
    # device = await discover_devices()

    # If a device is selected, connect and interact with it
    # if device:
        # await connect_and_interact(device)
        await connect_and_interact(None)

if __name__ == "__main__":
    asyncio.run(main())
